{% extends "admin/index.html" %} 
{% load i18n %} 

{% if not is_popup %}

{% block breadcrumbs %}
<div class="breadcrumbs"><a href="../">
{% trans "Home" %}</a> &rsaquo; 
{% for app in app_list %}
{% blocktrans with app.name as name %}{{ name }}{% endblocktrans %}
{% endfor %}</div>{% endblock %}

{% endif %} 


{% block sidebar %}

{# +++ CUSTOMIZATION STARTS HERE +++ #}
<div id="content-related">
    <div class="module">
        <h2>{% trans 'Administration' %}</h2>
        <h3>{% trans 'Data' %}</h3>
        <ul class="actionlist">
          <li><a href="{% url load-data %}">Load data</a></li>
          <li><a href="dump/">Dump data</a></li>
        </ul>
    </div>
</div>
{# +++ CUSTOMIZATION ENDS HERE +++ #}

{% endblock %}
